@@ -3,7 +3,7 @@ use Modern::Perl;
 use Moo::Role;
 use DateTime;
 
-our $VERSION = '0.0.5'; # VERSION
+our $VERSION = '0.0.6'; # VERSION
 # ABSTRACT: calculate total time that a program run
 
 
@@ -18,7 +18,7 @@ sub get_run_second  {
 }
 
 
-sub get_runtime_format {
+sub get_runtime {
   my $interval      = $_[0]->get_run_second;
   my $second        = $interval % 60;
   my $total_minute  = int ($interval / 60);
@@ -54,7 +54,7 @@ MooX::CalcTime::Role - calculate total time that a program run
 
 =head1 VERSION
 
-version 0.0.5
+version 0.0.6
 
 =head1 SYNOPSIS
 
@@ -85,7 +85,7 @@ So that we can obtain running time more easily.
 
 get total seconds passed from consumer class initialize to now.
 
-=head2 get_runtime_format
+=head2 get_runtime
 
 get total seconds, which passed from consumer class initialize to now, in a format
 of 'Running time: 8 days 4 hours 3 minutes 30 seconds'.
